[![GitHub Actions CI/CD build status — Collection test suite](https://github.com/ansible-collection-migration/community.azure/workflows/Collection%20test%20suite/badge.svg?branch=master)](https://github.com/ansible-collection-migration/community.azure/actions?query=workflow%3A%22Collection%20test%20suite%22)

Ansible Collection: community.azure
=================================================